---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
--
--
with Pex_Types ;
package Pex_Matrices is
    use Pex_Types ;
    
    Matrix_Error : exception ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Translate 
    --
    --  <Description>
    --
    --  Evaluates tha translation matrix associated to the given
    --  3D vector.
    --  
    --  <Parameters>
    --
    --  Vector : in Mc.Vector_3
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Translate ( Vector : in Mc.Vector_3 ;
                          Matrix : out Transformation_Matrix ) ;
  
    function Translate ( Vector : in Mc.Vector_3 )
        return Transformation_Matrix ;
   
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Translate 
    --
    --  <Description>
    --
    --  Evaluates tha translation matrix associated to the given
    --  2D vector.
    --  
    --  <Parameters>
    --
    --  Vector : in Mc.Vector_2
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Translate ( Vector : in Mc.Vector_2 ;
                          Matrix : out Transformation_Matrix_2 ) ;
     
    function Translate ( Vector : in Mc.Vector_2 )
        return Transformation_Matrix_2 ;
    
  
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Scale
    --
    --  <Description>
    --
    --  Evaluates tha transformation matrix associated to the
    --  given 3D vector.
    --  
    --  <Parameters>
    --
    --  Vector : in Mc.Vector_3
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Scale ( Vector : in Mc.Vector_3 ;
                      Matrix : out Transformation_Matrix ) ;

    function Scale ( Vector : in Mc.Vector_3 )
        return Transformation_Matrix ;
        
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Scale
    --
    --  <Description>
    --
    --  Evaluates tha transformation matrix associated to the
    --  given 2D vector.
    --  
    --  <Parameters>
    --
    --  Vector : in Mc.Vector_2
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Scale ( Vector : in Mc.Vector_2 ;
                      Matrix : out Transformation_Matrix_2 ) ;
    

    function Scale ( Vector : in Mc.Vector_2 )
        return Transformation_Matrix_2 ;
    

    --=====================================================================
    --  <Subprogram Name>
    --
    --  Rotate_X
    --
    --  <Description>
    --
    --  Evaluates tha transformation matrix associated to the
    --  given rotation around the X axis.
    --  
    --  <Parameters>
    --
    --  Angle_X: in Angle
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Rotate_X ( Angle_X : in Angle ;
                         Matrix  : out Transformation_Matrix ) ;
    
    function Rotate_X ( Angle_X : in Angle )
        return Transformation_Matrix ;
    

    --=====================================================================
    --  <Subprogram Name>
    --
    --  Rotate_Y
    --
    --  <Description>
    --
    --  Evaluates tha transformation matrix associated to the
    --  given rotation around the Y axis.
    --  
    --  <Parameters>
    --
    --  Angle_Y: in Angle
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Rotate_Y ( Angle_Y : in Angle ;
                         Matrix  : out Transformation_Matrix ) ;
    
    function Rotate_Y ( Angle_Y : in Angle )
        return Transformation_Matrix ;
    

    --=====================================================================
    --  <Subprogram Name>
    --
    --  Rotate_Z
    --
    --  <Description>
    --
    --  Evaluates tha transformation matrix associated to the
    --  given rotation around the Z axis.
    --  
    --  <Parameters>
    --
    --  Angle_Z: in Angle
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Rotate_Z ( Angle_Z : in Angle ;
                         Matrix  : out Transformation_Matrix ) ;
    
    function Rotate_Z ( Angle_Z : in Angle )
        return Transformation_Matrix ;
    


    --=====================================================================
    --  <Subprogram Name>
    --
    --  Rotate
    --
    --  <Description>
    --
    --  Evaluates the 2D transformation matrix associated to the
    --  given rotation around the Z axis.
    --  
    --  <Parameters>
    --
    --  Angle_Z: in Angle
    --  Matrix : out Transformation_Matrix 
    --
    --  <Errors Raised>
    --
    --=====================================================================
    procedure Rotate ( Angle_Z   : in Angle ;
                       Matrix    : out Transformation_Matrix_2 ) ;
    
    function Rotate ( Angle_Z : in Angle )
        return Transformation_Matrix_2 ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Compose_Matrix or "*"
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Matrix_A        : in Transformation_Matrix
    --  Matrix_B        : in Transformation_Matrix
    --  Composed_Matrix : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Compose_Matrix
        ( Matrix_A        : in Transformation_Matrix ;
          Matrix_B        : in Transformation_Matrix ;
          Composed_Matrix : out Transformation_Matrix ) ;
    
    function "*" ( Matrix_A        : in Transformation_Matrix ;
                   Matrix_B        : in Transformation_Matrix )
        return Transformation_Matrix ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Compose_Matrix or "*"
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Matrix_A        : in Transformation_Matrix_2
    --  Matrix_B        : in Transformation_Matrix_2
    --  Composed_Matrix : out Transformation_Matrix_2
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Compose_Matrix
        ( Matrix_A        : in Transformation_Matrix_2 ;
          Matrix_B        : in Transformation_Matrix_2 ;
          Composed_Matrix : out Transformation_Matrix_2 ) ;
    
    function "*" ( Matrix_A        : in Transformation_Matrix_2 ;
                   Matrix_B        : in Transformation_Matrix_2 )
        return Transformation_Matrix_2 ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Transform_Point 
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Point  : in Mc.Point_3
    --  Matrix : in Transformation_Matrix
    --  Transformed_Point : out Mc.Point_3
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Transform_Point ( Point  : in Mc.Point_3 ;
                                Matrix : in Transformation_Matrix ;
                                Transformed_Point : out Mc.Point_3) ;
    
    function Transform_Point ( Point  : in Mc.Point_3 ;
                               Matrix : in Transformation_Matrix )
        return Mc.Point_3 ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Transform_Point 
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Point  : in Mc.Point_2
    --  Matrix : in Transformation_Matrix_2
    --  Transformed_Point : out Mc.Point_2
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Transform_Point ( Point  : in Mc.Point_2 ;
                                Matrix : in Transformation_Matrix_2 ;
                                Transformed_Point : out Mc.Point_2) ;
    
    function Transform_Point ( Point  : in Mc.Point_2 ;
                               Matrix : in Transformation_Matrix_2 )
        return Mc.Point_2 ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Build_Transformation_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Fixed_Point   : in Mc.Point_3
    --  Shift_Vector  : in Mc.Vector_3
    --  Angle_X       : in Angle
    --  Angle_Y       : in Angle
    --  Angle_Z       : in Angle
    --  Scale_Factors : in Mc.Vector_3
    --  Matrix        : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Build_Transformation_Matrix
        ( Fixed_Point   : in Mc.Point_3 ;
          Shift_Vector  : in Mc.Vector_3 ;
          Angle_X       : in Angle ;
          Angle_Y       : in Angle ;
          Angle_Z       : in Angle ;
          Scale_Factors : in Mc.Vector_3 ;
          Matrix        : out Transformation_Matrix ) ;
    
    function Matrix
        ( Fixed_Point   : in Mc.Point_3 ;
          Shift_Vector  : in Mc.Vector_3 ;
          Angle_X       : in Angle ;
          Angle_Y       : in Angle ;
          Angle_Z       : in Angle ;
          Scale_Factors : in Mc.Vector_3 )
        return Transformation_Matrix ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Build_Transformation_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Fixed_Point   : in Mc.Point_2
    --  Shift_Vector  : in Mc.Vector_2
    --  Angle_Z       : in Angle
    --  Scale_Factors : in Mc.Vector_2
    --  Matrix        : out Transformation_Matrix_2
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Build_Transformation_Matrix
        ( Fixed_Point   : in Mc.Point_2 ;
          Shift_Vector  : in Mc.Vector_2 ;
          Angle_Z       : in Angle ;
          Scale_Factors : in Mc.Vector_2 ;
          Matrix        : out Transformation_Matrix_2 ) ;
    
    function Matrix
        ( Fixed_Point   : in Mc.Point_2 ;
          Shift_Vector  : in Mc.Vector_2 ;
          Angle_Z       : in Angle ;
          Scale_Factors : in Mc.Vector_2 )
        return Transformation_Matrix_2 ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Evaluate_View_Orientation_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Reference_Point    : in Wc.Point_3
    --  Normal_Vector      : in Wc.Vector_3
    --  Up_Vector          : in Wc.Vector_3
    --  Orientation_Matrix : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Evaluate_View_Orientation_Matrix
        ( Reference_Point    : in Wc.Point_3 ;
          Normal_Vector      : in Wc.Vector_3 ;
          Up_Vector          : in Wc.Vector_3 ;
          Orientation_Matrix : out Transformation_Matrix ) ;
    
    function View_Orientation_Matrix
        ( Reference_Point    : in Wc.Point_3 ;
          Normal_Vector      : in Wc.Vector_3 ;
          Up_Vector          : in Wc.Vector_3 )
        return Transformation_Matrix ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Evaluate_View_Orientation_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Reference_Point    : in Wc.Point_2
    --  Up_Vector          : in Wc.Vector_2
    --  Orientation_Matrix : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Evaluate_View_Orientation_Matrix
        ( Reference_Point    : in Wc.Point_2 ;
          Up_Vector          : in Wc.Vector_2 ;
          Orientation_Matrix : out Transformation_Matrix ) ;
    
    function View_Orientation_Matrix
        ( Reference_Point    : in Wc.Point_2 ;
          Up_Vector          : in Wc.Vector_2 )
        return Transformation_Matrix ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Evaluate_View_Mapping_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Window_Limits      : in Vrc.Rectangular_Region_2
    --  Viewport_Limits    : in Npc.Rectangular_Region_3
    --  Type_Of_Projection : in Projection_Type
    --  Reference_Point    : in Vrc.Point_3
    --  View_Distance      : in Vrc_Type
    --  Back_Distance      : in Vrc_Type
    --  Front_Distance     : in Vrc_Type
    --  Mapping_Matrix     : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Evaluate_View_Mapping_Matrix
        ( Window_Limits      : in Vrc.Rectangular_Region_2 ;
          Viewport_Limits    : in Npc.Rectangular_Region_3 ;
          Type_Of_Projection : in Projection_Type ;
          Reference_Point    : in Vrc.Point_3 ;
          View_Distance      : in Vrc_Type ;
          Back_Distance      : in Vrc_Type ;
          Front_Distance     : in Vrc_Type ;
          Mapping_Matrix     : out Transformation_Matrix ) ;
    
    function View_Mapping_Matrix
        ( Window_Limits      : in Vrc.Rectangular_Region_2 ;
          Viewport_Limits    : in Npc.Rectangular_Region_3 ;
          Type_Of_Projection : in Projection_Type ;
          Reference_Point    : in Vrc.Point_3 ;
          View_Distance      : in Vrc_Type ;
          Back_Distance      : in Vrc_Type ;
          Front_Distance     : in Vrc_Type )
        return Transformation_Matrix ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Evaluate_View_Mapping_Matrix
    --
    --  <Description>
    --
    --  xxxxxxxxxx
    --  
    --  <Parameters>
    --
    --  Window_Limits      : in Vrc.Rectangular_Region_2
    --  Viewport_Limits    : in Npc.Rectangular_Region_2
    --  Mapping_Matrix     : out Transformation_Matrix
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Evaluate_View_Mapping_Matrix
        ( Window_Limits      : in Vrc.Rectangular_Region_2 ;
          Viewport_Limits    : in Npc.Rectangular_Region_2 ;
          Mapping_Matrix     : out Transformation_Matrix ) ;
    
    function View_Mapping_Matrix
        ( Window_Limits      : in Vrc.Rectangular_Region_2 ;
          Viewport_Limits    : in Npc.Rectangular_Region_2 )
        return Transformation_Matrix ;
    
end Pex_Matrices ;
