---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
-- 
--   Package : Pex_Lookup_Tables
-- 
--   Version : 
-- 
--   Subject : PEX Lookup Table functions:
-- 
--   Section 4.1 -- Lookup Table Resource Management
--   Create_Lookup_Table     
--   Copy_Lookup_Table       
--   Free_Lookup_Table       --  Free instead of Delete ...  (jcm)
--  
--   Section 4.2 -- Lookup Table Inquiry
--   Get_Table_Information        
--   Get_Predefined_Entries   
--   Get_Defined_Indices     
--   Get_Table_Entry         
--   Get_Table_Entries       
--  
--   Section 4.3 -- Lookup Table Modification
--   Set_Table_Entries       
--   Delete_Table_Entries         
--  
with X_Types;
with Pex_Types;
--  
package Pex_Lookup_Tables is  
--  
    use X_Types;
    use Pex_Types;
--  
--   Section 4.1 -- Lookup Table Resource Management
--   
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Create_Lookup_Table
    --
    --  <Description>
    --
    -- This request creates a lookup table resource for the
    -- specified lut_id , for use with drawables with the same
    -- root window and depth as the example drawable specified by
    -- drawable_example . The table_type parameter indicates the
    -- type of lookup table that is to be created. Some entries
    -- of a lookup table may be defined at the time the resource
    -- is created. The number of predefined entries and their
    -- contents are dependent on the type of table and are
    -- implementation-dependent.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Drawable_Id : The drawable.
    --  Table_Type  : The type of the lookup table.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    function Create_Lookup_Table
        ( Display_Id  : in Display;
          Drawable_Id : in Drawable;
          Table_Type  : in Lookup_Table_Type) return Lookup_Table;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Copy_Lookup_Table
    --
    --  <Description>
    --
    -- This request copies the source lookup table src_lut to
    -- a destination lookup table dest_lut, after first
    -- deleting all the entries in the destination lookup table.
    -- The dest_lut must already exist as a valid resource and
    -- it must be of the same type as src_lut.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Src_Lut    : The lookup table to copy.
    --  Dst_Lut    : The destination lookup table.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Copy_Lookup_Table ( Display_Id : in Display;
                                  Src_Lut    : in Lookup_Table;
                                  Dst_Lut    : in Lookup_Table);
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Free_Lookup_Table
    --
    --  <Description>
    --
    -- This request deletes the association between the resource
    -- ID and the lookup table. The lookup table storage will be
    -- freed when no other resource references it.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Lut_Id      : The lookup table.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Free_Lookup_Table ( Display_Id  : in Display;
                                  Lut_Id      : in Lookup_Table); 
--
--  Section 4.2 -- Lookup Table Inquiry
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Table_Information
    --
    --  <Description>
    --
    -- This request will return information about lookup tables
    -- of the specified table_type if they were to be used with
    -- drawables of the same root and depth as drawable_example.
    -- Definable_entries is the maximum number of entries that
    -- can be defined in this type of table, and includes the
    -- number of predefined entries. Predefined entries can be
    -- redefined by the client. All the entries between
    -- predefined_min and predefined_max are guaranteed to be
    -- defined initially (i.e., predefined entries must have
    -- contiguous indices)If num_predefined is zero, then the
    -- values for predefined_min and predefined_max are
    -- meaningless.
    --
    --  <Parameters>
    --
    --  Display_Id        : The X Server connection.
    --  Drawable_Id       : The drawable.
    --  Table_Type        : The type of the lookup table. 
    --  Definable_Entries : 
    --  Num_Predefined    : 
    --  Predefined_Min    : 
    --  Predefined_Max    : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Table_Information
        ( Display_Id        : in Display;
          Drawable_Id       : in Drawable;
          Table_Type        : in Lookup_Table_Type;
          Definable_Entries : out Lookup_Table_Index;
          Num_Predefined    : out Lookup_Table_Index;
          Predefined_Min    : out Lookup_Table_Index;
          Predefined_Max    : out Lookup_Table_Index);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Predefined_Entries
    --
    --  <Description>
    --
    -- This request will return the values for predefined table
    -- entries of the specified table_type if they were to be
    -- used with drawables of the same root and depth as
    -- drawable_example . The default entry will be returned for
    -- each entry in the range that is not predefined. Count
    -- table entries will be returned in entries , starting with
    -- the table entry specified by start . The values in entries
    -- will be in the format defined for table_type . Floating
    -- point values in entries will be returned in the floating
    -- point format specified in fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Drawable_Id : The drawable.
    --  Table_Type  : The type of the lookup table. 
    --  Start       : 
    --  Count       : 
    --  Entries     : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Predefined_Entries
        ( Display_Id  : in Display;
          Drawable_Id : in Drawable;
          Table_Type  : in Lookup_Table_Type;
          Start       : in Lookup_Table_Index;
          Count       : in Lookup_Table_Index;
          Entries     : out Lookup_Table_Entry_List);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Defined_Indices
    --
    --  <Description>
    --
    -- This request will return in defined_indices a list of all
    -- the indices that are currently defined in the lookup table
    -- resource specified by lut_id . The entries returned 
    -- include those predefined by the server and those that have
    -- been defined by clients.
    --
    --  <Parameters>
    --
    --  Display_Id      : The X Server connection.
    --  Lut_Id          : The lookup table.
    --  Defined_Indices : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Defined_Indices
        ( Display_Id      : in Display;
          Lut_Id          : in Lookup_Table;
          Defined_Indices : out Lookup_Table_Index_List);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Table_Entry
    --
    --  <Description>
    --
    -- This request will return the type of lookup table and the
    -- lookup table entry specified by index . The entry will be
    -- obtained from the lookup table specified by lut_id and
    -- will be of the format indicated by lut_id 's table type.
    -- If the specified entry in the lookup table is not defined,
    -- the values for the default entry for that table type will
    -- be returned in entry and status will be set to Default .
    -- If the specified entry is defined, its contents will be
    -- returned in entry and status will be set to Defined . If
    -- value_type is Set , the values returned will be those
    -- originally specified by the client. If value_type is
    -- Realized , the values returned will be the values that are
    -- actually used during rendering (i.e., the default values,
    -- which are used if the specified value is not supported on
    -- the drawable)Floating point values in entry will be
    -- returned in the floating point format specified in
    -- fp_format.
    --
    --  <Parameters>
    --
    --  Display_Id   : The X Server connection.
    --  Lut_Id       : The lookup table.  
    --  Index        : The index of the desired entry.
    --  Value_Type   : 
    --  Entry_Status : 
    --  Table_Entry  : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Table_Entry
        ( Display_Id   : in Display;
          Lut_Id       : in Lookup_Table;
          Index        : in Lookup_Table_Index;
          Value_Type   : in Lookup_Table_Value_Type;
          Entry_Status : out Lookup_Table_Entry_Status;
          Table_Entry  : out Lookup_Table_Entry);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Table_Entries
    --
    --  <Description>
    --
    -- This request will return the type of table and count table
    -- entries from the lookup table specified by lut_id ,
    -- starting at the entry specified by start . The default
    -- entry will be returned for any entry in the requested
    -- range that is not defined. If value_type is Set , the
    -- values returned will be those originally specified by the
    -- client. If value_type is Realized , the values returned
    -- will be the values that are actually used during rendering
    -- (i.e., the default values, which are used if the specified
    -- value is not supported on the drawable)Floating point
    -- values in entries will be returned in the floating point
    -- format specified in fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id    : The X Server connection.
    --  Lut_Id        : The lookup table.
    --  Start         : 
    --  Count         : 
    --  Value_Type    : 
    --  Entries       : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Table_Entries
        ( Display_Id    : in Display;
          Lut_Id        : in Lookup_Table;
          Start         : in Lookup_Table_Index;
          Count         : in Lookup_Table_Index;
          Value_Type    : in Lookup_Table_Value_Type;
          Entries       : out Lookup_Table_Entry_List);
-- 
--  Section 4.3 -- Lookup Table Modification
-- 
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Set_Table_Entries
    --
    --  <Description>
    --
    -- This request will set count lookup table entries in the
    -- lookup table resource specified by lut_id , starting at
    -- the entry indicated by start . The values to use when
    -- setting the entries in the lookup table are provided in
    -- entries , and are in the format specified for a lookup
    -- table of lut_id 's type. Floating point values in entries
    -- will be in the floating point format specified in
    -- fp_format .
    --
    --  <Parameters>
    --
    --  Display_Id    : The X Server connection.
    --  Lut_Id        : The lookup table.
    --  Table_Entries : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Set_Table_Entries
        ( Display_Id    : in Display;
          Lut_Id        : in Lookup_Table;
          Table_Entries : in Lookup_Table_Entry_Array);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Delete_Table_Entries
    --
    --  <Description>
    --
    -- This request will delete the defined table entries in the
    -- lookup table resource specified by lut_id , between | and
    -- including the entry specified by start and the entry
    -- specified by start + count -1.
    --
    --  <Parameters>
    --
    --  Display_Id    : The X Server connection.
    --  Lut_Id        : The lookup table.
    --  Start         : First index of entry to delete.
    --  Finish        : Last index of entry to delete.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Delete_Table_Entries
        ( Display_Id    : in Display;
          Lut_Id        : in Lookup_Table;
          Start         : in Lookup_Table_Index;
          Finish        : in Lookup_Table_Index);
end Pex_Lookup_Tables;
