---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
--  
--  Package : Pex_Name_Sets
--
--  Version :
--
--  Subject : PEX Name Set functions
--
--  Section 8.1 -- Name Set Resource Management
--  Create_Name_Set
--  Copy_Name_Set       
--  Delete_Name_Set
--  
--  Section 8.2 -- Name Set Inquiry
--  Get_Name_Set        
-- 
--  Section 8.3 -- Name Set Modification
--  Change_Name_Set     
--  
--  
with X_Types;
with Pex_Types;
--  
package Pex_Name_Sets is
--  
    use X_Types;
    use Pex_Types;
--  
--  Section 8.1 -- Name Set Resource Management
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Create_Name_Set
    --
    --  <Description>
    --
    --  This request creates a name set resource for the
    --  returned ns_id . The name set is initialized to an empty
    --  list when the resource is created.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --
    --  <Errors Raised>
    --
    --=====================================================================

  function Create_Name_Set ( Display_Id : in Display) return Name_Set;

    --=====================================================================
    --  <Subprogram Name>
    --
    --  Copy_Name_Set
    --
    --  <Description>
    --
    --  This request copies the source name set src_ns_id to a
    --  destination name set dest_ns_id after first emptying the
    --  contents of dest_ns_id . The dest_ns_id must already
    --  exist as a valid resource.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Src_Set    : The name set to copy.
    --  Dst_Set    : The destination name set.
    --
    --  <Errors Raised>
    --
    --=====================================================================

  procedure Copy_Name_Set ( Display_Id : in Display;
                            Src_Set    : in Name_Set;
                            Dst_Set    : in Name_Set);
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Delete_Name_Set
    --
    --  <Description>
    --
    --  This request deletes the association between the resource
    --  ID and the name set. The name set storage will be freed
    --  when no other resource references it.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Set        : The name set to delete.
    --
    --  <Errors Raised>
    --
    --=====================================================================

  procedure Delete_Name_Set ( Display_Id : in Display;
                              Set        : in Name_Set);
--
--
--  Section 8.2 -- Name Set Inquiry
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Name_Set
    --
    --  <Description>
    --
    --  This request will return the contents of the name set
    --  specified by ns_id .
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Set        : The name set to inquire about.
    --  Names      : The content of the name set.
    --
    --  <Errors Raised>
    --
    --=====================================================================

  procedure Get_Name_Set ( Display_Id : in Display;
                           Set        : in Name_Set;
                           Names      : out Name_List);
--
--  Section 8.3 -- Name Set Modification
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Change_Name_Set
    --
    --  <Description>
    --
    --  This request changes the contents of a name set resource.
    --  If action is Add , the specified list of names is added
    --  to the name set. If action is Remove , the specified list
    --  of names is removed from the name set. If action is
    --  Replace , all the names in the name set are removed, then
    --  the specified list of names is added to the name set.
    --
    --  <Parameters>
    --
    --  Display_Id : The X Server connection.
    --  Set        : The name set to modify.
    --  Action     : The modification to do.
    --  Names      : Tne names used for modification.
    --
    --  <Errors Raised>
    --
    --=====================================================================

  procedure Change_Name_Set ( Display_Id : in Display;
                              Set        : in Name_Set;
                              Action     : in Name_Set_Action;
                              Names      : in Name_List);
end Pex_Name_Sets;
