---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
--
-- This Ada language binding to the PEX extension to the X Window System
-- inherits the Sun Microsystem copyright. The following copyright must
-- be included in all software utilising this binding.
--
-- Copyright 1992 J.C. Mahieux and B. Maudry
-- Copyright 1989, 1990, 1991 by Sun Microsystems, Inc. and the X Consortium.
--
--  
--   Package : Pex_Rendering
--
--   Version :
--
--   Subject : PEX Renderer Functions
--
--   Section 6.1 -- Renderer Resource Management 
--   Create_Renderer
--   Free_Renderer
--
--   Section 6.2 -- Renderer Modification
--   Change_Renderer
--
--   Section 6.3 -- Renderer Inquiry
--   Get_Renderer_Attributes
--   Get_Renderer_Dynamics
--
--   Section 6.4 -- Client-Side Traversal Support
--   Begin_Rendering
--   End_Rendering
--   Begin_Structure
--   End_Structure
--
--   Section 6.5 -- Rendering Commands
--   Render_Output_Commands
--   Render_Elements
--   Accumulate_State
--   Render_Network
--
-- 
with X_Types;
with Pex_Types;
-- 
package Pex_Rendering is 
-- 
    use X_Types;
    use Pex_Types;
-- 
--  
--   Section 6.1 -- Renderer Resource Management
--
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Create_Renderer
    --
    --  <Description>
    --
    -- This request creates a renderer resource for the specified
    -- rdr_id . It can be used to render onto drawables with the
    -- same root window and depth as the example drawable
    -- specified by drawable_example . The item_mask defines
    -- those renderer attributes that are to be explicitly set at
    -- the time the resource is created. The item_list contains
    -- the corresponding list of values used to modify the
    -- newly-created renderer. Floating point values in item_list
    -- will be in the floating point format specified in
    -- fp_format.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Drawable_ex : Drawable to define root window and depth.
    --  Mask        : Renderer attributes to be set.
    --  Items       : Corresponding renderer values.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    function Create_Renderer ( Display_Id  : in Display;
                               Drawable_ex : in Drawable;
                               Mask        : in Renderer_Bitmask;
                               Items       : in Renderer_Values)
        return Renderer;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Free_Renderer
    --
    --  <Description>
    --
    -- This request deletes the specified renderer resource and
    -- frees the storage associated with it. If the renderer's
    -- renderer_state attribute is set to Rendering when this
    -- request is processed, an implicit PEXEndRendering request
    -- with flush equal to False will be performed before the
    -- renderer is freed.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer to free.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Free_Renderer ( Display_Id : in Display;
                              Renderer_Id : in Renderer);
    
    --
    --    Section 6.2 -- Renderer Modification
    --
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Change_Renderer
    --
    --  <Description>
    --
    -- This request changes components of a renderer. The
    -- item_mask and item_list specify which components are to be
    -- changed. Each bit in the item_mask indicates whether or
    -- not there is a corresponding entry in the item_list . It
    -- is therefore possible to modify one or many renderer
    -- attributes with a PEXChangeRenderer request. A renderer's
    -- current_path and renderer_state attribute are read-only,
    -- therefore attempts to modify them will be ignored.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer to modify.
    --  Mask        : Renderer attributes to be change.
    --  Items       : Corresponding renderer values.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Change_Renderer ( Display_Id : in Display;
                                Renderer_Id : in Renderer;
                                Mask        : in Renderer_Bitmask;
                                Items       : in Renderer_Values);
    --
    --    Section 6.3 -- Renderer Inquiry
    --
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Renderer_Attributes
    --
    --  <Description>
    --
    -- This request will return components of the renderer
    -- specified by rdr_id . The item_mask specifies which
    -- components are to be inquired and returned. The specified
    -- attributes of the renderer will be returned in item_list .
    -- Floating point values in item_list will be returned in the
    -- floating point format specified in | fp_format . (The
    -- values returned are those that were last set by the
    -- client. Depending on the dynamics of the renderer, these
    -- may or may not be the values currently in use. See
    -- PEXGetRendererDynamics.)
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer whose attributes are wanted.
    --  Mask        : Renderer attributes to be get.
    --  Items       : Corresponding renderer values.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Renderer_Attributes ( Display_Id : in Display;
                                        Renderer_Id : in Renderer;
                                        Mask        : in Renderer_Bitmask;
                                        Items       : in out Renderer_Values);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Get_Renderer_Dynamics
    --
    --  <Description>
    --
    -- This request will return the dynamics (binding times)for
    --  all of the attributes of the specified renderer. The
    -- tables bitmask has the following bits defined:
    -- MarkerBundle MarkerBundleContents TextBundle
    -- TextBundleContents LineBundle LineBundleContents
    -- InteriorBundle InteriorBundleContents EdgeBundle
    -- EdgeBundleContents ViewTable ViewTableContents ColorTable
    -- ColorTableContents DepthCueTable DepthCueTableContents
    -- LightTable LightTableContents ColorApproxTable
    -- ColorApproxTableContents PatternTable PatternTableContents
    -- TextFontTable TextFontTableContents The namesets bitmask
    -- has the following bits defined: HighlightNameset
    -- HighlightNamesetContents InvisibilityNameset
    -- InvisibilityNamesetContents The attributes bitmask has the
    -- following bits defined: HLHSRMode NPCSubvolume Viewport
    -- ClipList For each defined bit, a value of zero indicates
    -- that the specified attribute may be modified at any time,
    -- and the contents will take effect immediately. A value of
    -- one indicates that the specified attribute may not be
    -- modified dynamically. A change to such an attribute is
    -- said to be "pending" and will take effect at the next
    -- explicit or implicit PEXBeginRendering . Implementations
    -- that allow attributes such as HLHSRMode to be modified at
    -- any time must specify the semantics of changing between
    -- all possible supported values for that attribute. 
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer whose attributes are wanted.
    --  Tables      : 
    --  Namesets    : 
    --  Attributes  : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Get_Renderer_Dynamics
        ( Display_Id  : in Display;
          Renderer_Id : in Renderer;
          Tables      : out Renderer_Tables_Bitmask;
          Namesets    : out Renderer_Name_Set_Bitmask;
          Attributes  : out Renderer_Attributes_Bitmask);
    
    --
    --    Section 6.4 -- Client-Side Traversal Support
    --
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Begin_Rendering
    --
    --  <Description>
    --
    -- This request causes rendering to begin on the drawable
    -- specified by drawable_id . The output of the renderer
    -- specified by rdr_id is bound to that drawable until a
    -- PEXEndRendering request is processed. The initial
    -- rendering pipeline attributes are copied into the renderer
    -- from the pipeline context specified by the renderer's
    -- pipeline_context attribute. If pipeline_context is Null ,
    -- the default values for all of the attributes in a pipeline
    -- context are copied into the renderer instead. The
    -- renderer's renderer_state attribute is set to Rendering
    -- and its current_path attribute is set to the null list. If
    -- the specified drawable does not have the same root and
    -- depth as the drawable that was passed in the request to
    -- create the renderer, a Match error will be generated. If
    -- the renderer's renderer_state attribute is | currently set
    -- to Rendering , an implicit PEXEndRendering request is
    -- performed (with flush equal to False )The
    -- PEXBeginRendering request will then be executed, and a
    -- RendererState error will be returned after executing the
    -- request.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer to use.
    --  Drawable_Id : The drawable where rendering takes place.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Begin_Rendering ( Display_Id  : in Display;
                                Renderer_Id : in Renderer;
                                Drawable_Id : in Drawable);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  End_Rendering
    --
    --  <Description>
    --
    -- If flush is True , this request causes any pending output
    -- for the renderer specified by rdr_id to be rendered onto
    -- the drawable. If flush is False , pending output for the
    -- renderer is discarded. In either case, the renderer_state
    -- attribute of the renderer is set to Idle . If the
    -- renderer_state attribute is currently Idle (i.e., no
    -- rendering is in progress or the rendering was aborted due
    -- to a resize)the request is ignored and no error is
    -- generated.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The concerned renderer.
    --  Flush       : 
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure End_Rendering ( Display_Id  : in Display;
                              Renderer_Id : in Renderer;
                              Flush       : in Boolean);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Begin_Structure
    --
    --  <Description>
    --
    -- This request causes the rendering pipeline attributes in
    -- the renderer specified by rdr_id to be saved. The
    -- attributes of the renderer resource itself (i.e., the
    -- attributes of a renderer that can be set/queried,
    -- including | table and name set resource IDs)are not saved.
    -- The element offset of the last entry in the renderer's
    -- current_path is incremented (to account for the
    -- client-side "execute structure" command)then the name
    -- specified by s_id together with an element offset of zero
    -- (indicating an empty structure)is appended to the |
    -- current_path attribute. Each subsequent output command
    -- will cause the element offset to be incremented by one
    -- until the next PEXBeginStructure request or the next
    -- PEXEndStructure request. After saving the current
    -- rendering pipeline attributes, the global_transform
    -- attribute is set to the matrix computed by concatenating
    -- the current local_transform and the current
    -- global_transform matrices. Then the local_transform matrix
    -- is set to the identity matrix.
    --
    --  <Parameters>
    --
    --  Display_Id   : The X Server connection.
    --  Renderer_Id  : The renderer.
    --  Structure_Id : The structure.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Begin_Structure ( Display_Id   : in Display;
                                Renderer_Id  : in Renderer ;
                                Structure_Id : in User_Structure ) ;
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  End_Structure
    --
    --  <Description>
    --
    -- This request restores the last-saved rendering pipeline
    -- attributes in the renderer specified by rdr_id . In
    -- addition, the last element reference in the renderer's
    -- current_path is removed, and subsequent output commands
    -- will cause the element offset of the element reference at
    -- the end of the list to be incremented. This request itself
    -- does not cause an increment to current_path.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure End_Structure ( Display_Id   : in Display;
                              Renderer_Id  : in Renderer);
    
    --
    --    Section 6.5 -- Rendering Commands
    --
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Render_Output_Commands
    --
    --  <Description>
    --
    -- If the renderer_state attribute of the renderer specified
    -- by rdr_id is set to Rendering , the output commands in
    -- cmds will be immediately processed. If the renderer_state
    -- attribute is set to Idle , the commands will be ignored.
    -- Floating point values in cmds will be in the floating
    -- point format specified in fp_format . The formats for the
    -- various types of output commands can be found Section 3 -
    -- Output Commands . Output commands are processed by the
    -- server in order until one is found to be in error, or
    -- until the entire list has been processed. The erroneous
    -- output command and all others following it in the request
    -- are ignored, and an OutputCommand error is returned to the
    -- client. The current_path attribute of the renderer is
    -- updated to reflect only those output commands actually
    -- processed.
    --
    --  <Parameters>
    --
    --  Display_Id  : The X Server connection.
    --  Renderer_Id : The renderer.
    --  Commands    : The buffer of commands to render.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Render_Output_Commands ( Display_Id  : in Display;
                                       Renderer_Id : in Renderer;
                                       Commands    : in Output_Command_Buffer);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Render_Elements
    --
    --  <Description>
    --
    --  <Parameters>
    --
    --  Display_Id   : The X Server connection.
    --  Renderer_Id  : The renderer.
    --  Structure_Id : The source structure.
    --  Between      : Range of elements to render.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Render_Elements ( Display_Id   : in Display;
                                Renderer_Id  : in Renderer;
                                Structure_Id : in Structure;
                                Between      : in Element_Range);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Accumulate_State
    --
    --  <Description>
    --
    --  <Parameters>
    --
    --  Display_Id   : The X Server connection.
    --  Renderer_Id  : The renderer.
    --  Path         : The path to accumulate up to.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Accumulate_State ( Display_Id   : in Display;
                                 Renderer_Id  : in Renderer;
                                 Path         : in Element_Reference_Array);
    
    --=====================================================================
    --  <Subprogram Name>
    --
    --  Render_Network
    --
    --  <Description>
    --
    -- This request causes the structure network rooted at s_id
    -- to be traversed and rendered on drawable_id , using the
    -- renderer specified by rdr_id . This functionality is
    -- equivalent to the following (pseudo-)PEXBeginRendering (
    -- rdr_id , drawable_id )PEXRenderOutputCommands ( rdr_id ,
    -- all elements of s_id )PEXEndRendering ( rdr_id , True ).
    --
    --  <Parameters>
    --
    --  Display_Id   : The X Server connection.
    --  Renderer_Id  : The renderer.
    --  Drawable_Id  : The drawable.
    --  Structure_Id : The root structure.
    --
    --  <Errors Raised>
    --
    --=====================================================================

    procedure Render_Network ( Display_Id   : in Display;
                               Renderer_Id  : in Renderer;
                               Drawable_Id  : in Drawable;
                               Structure_Id : in Structure);
end Pex_Rendering;
