he Massachusetts Institute of Technology
--
------------------ Distribution and Copyright -----------------
-- Derivation   : MIT X Window System, V11.R4
--
-- This Ada language binding to the X Window System inherits
-- the MIT copyright. The following copyright must be included
-- in all software utilising this binding.
--
-- Copyright 1990, 1991 J.C. Mahieux and B. Maudry
-- Copyright 1985, 1986, 1987 by the Massachusetts Institute of Technology
--
with X_Types ;
with System ;
package X_Image is
    use X_Types ;

    type Image_Range is range 0 .. System.Max_Int ;
    type Image_Bytes is array (Image_Range range <>) of Byte ;
    type Image_Data is access Image_Bytes ;
    
    --======================================================================
    --  <Subprogram Name>
    --
    --  Create_Image
    --
    --  <Description>
    --
    --  This function create an image data structure for the display.
    --  It does not allocate the space for the image itself but initializes
    --  the structure with given values.
    --  Care should be taken as the image data provided are referenced by the
    --  structure and any subsequent modification is automatically effective.
    --
    --  <Parameters>
    --
    --  Display_Id      : Specifies the connection to the X Server.
    --  Visual_Id       : Specifies the visual.
    --  Depth           : Specifies the depth.
    --  Format          : Specifies the pixmap format.
    --  Offset          : Specifies the number of pixels to ignore at
    --                    the start of the scanline.
    --  Data            : Specifies the image data.
    --  Width           : Specifies the width of the image.
    --  Height          : Specifies the height of the image.
    --  Scanline_Pad    : Specifies the scanline separation pad.
    --  Bytes_Per_Line  : Specifies the length of a scanline and its pad.
    --
    --  <Called By>
    --
    --  External.
    --
    --======================================================================

    function Create_Image ( Display_Id      : in Display ;
                            Visual_Id       : in Visual ;
                            Depth           : in Depth_Type ;
                            Format          : in Pixmap_Format ;
                            Offset          : in Pixels ;
                            Data            : in Image_Data ;
                            Width           : in Pixels ;
                            Height          : in Pixels ;
                            Scanline_Pad    : in Pixels ;
                            Bytes_Per_Line  : in Pixels) return Image ;

    --========================================================================
    --  <Subprogram Name>
    --
    --  Get_Image
    --
    --  <Description>
    --
    --  This function returns the contents of a rectangle in the drawable
    --  as an Image.
    --
    --  <Parameters>
    --
    --  Display_Id      : Specifies the connection to the X Server.
    --  Drawable_Id     : Specifies the drawable (pixmap or window).
    --  Source          : Specifies the source rectangle.
    --  Planes          : Specifies the plane mask.
    --  Format          : Specifies either XY_Pixmap or Z_Pixmap.
    --  
    --
    --  <Exceptions Raised>
    --
    --  Bad_Match is raised if the destination window is input only.
    --  Bad_Drawable is raised if the drawable is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    function Get_Image ( Display_Id  : in Display;
                         Drawable_Id : in Drawable;
                         Source      : in Rectangle;
                         Planes      : in Plane_Mask;
                         Format      : in Pixmap_Format) return Image ;

    --========================================================================
    --  <Subprogram Name>
    --
    --  Put_Image
    --
    --  <Description>
    --
    --  This procedure combines an image in memory with a rectangle of a 
    --  drawable on your display.
    --
    --  <Parameters>
    --
    --  Display_Id      : Specifies the connection to the X Server.
    --  Drawable_Id     : Specifies the drawable (pixmap or window).
    --  GC              : Specifies the graphics context.
    --  X_Image         : Specifies the image to combine with the rectangle.
    --  Source_XY       : Specifies the offset from the image origin.
    --  Destination     : Specifies the rectangle of the drawable.
    --  
    --
    --  <Exceptions Raised>
    --
    --  Bad_Match is raised if the destination window is input only.
    --  Bad_Drawable is raised if the drawable is invalid.
    --  Bad_GC is raised if the graphics context is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Put_Image ( Display_Id  : in Display ;
                          Drawable_Id : in Drawable ;
                          Gc          : in Graphic_Context ;
                          X_Image     : in Image ;
                          Source_Xy   : in Point ;
                          Destination : in Rectangle) ;
end X_Image ;
