---------------------------------------------------------------
--
--                    Top Graph'X
--
-- For any information call J.C. Mahieux :
-- Tel : (33) 1 69 26 97 88
-- Fax : (33) 1 69 26 97 89
--
-- Top Graph'X - 10 Allee de la Mare Jacob
--               91290 La Norville- FRANCE
--
---------------------------------------------------------------
--
------------------ Distribution and Copyright -----------------
-- Derivation   : MIT X Window System, V11.R4
--
-- This Ada language binding to the X Window System inherits
-- the MIT copyright. The following copyright must be included
-- in all software utilising this binding.
--
-- Copyright 1990, 1991 J.C. Mahieux and B. Maudry
-- Copyright 1985, 1986, 1987 by the Massachusetts Institute of Technology
--
with X_Types ;

package X_Window_Actions is
use X_Types ;
    
    --====================================================================
    --  <Subprogram Name>
    --
    --  Change_Window_Attributes
    --
    --  <Description>
    --
    -- This procedure changes one or more window attributes.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Value_Mask : Specifies which window attributes to change.
    --  Attributes : Specifies the value of the attributes.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Access is raised if a selected event is reserved.
    --  Bad_Window is raised if the Window_Id is invalid.
    --  Bad_Cursor is raised if the cursor is invalid.
    --  Bad_Color is raised if the color map is invalid.
    --  Bad_Pixmap is raised if a pixmap is invalid.
    --  Bad_Match is raised if the window is an input only window.
    --  Bad_Value is raised if any of the other values is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Change_Window_Attributes
        ( Display_Id : in Display;
          Window_Id  : in Window;
          Value_Mask : in Wa_Mask_Type;
          Attributes : in Set_Window_Attributes_Record);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Circulate_Subwindows
    --
    --  <Description>
    --
    -- This procedure circulates the subwindows of the specified window
    -- in the specified direction.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Direction  : Specifies Raise_Lowest or Raise_Highest.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Circulate_Subwindows ( Display_Id : in Display;
                                     Window_Id  : in Window;
                                     Direction  : in Direction_Type) ;


    --========================================================================
    --  <Subprogram Name>
    --
    --  Circulate_Subwindows_Down
    --
    --  <Description>
    --
    -- This procedure lowers the highest mapped child of the specified window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Circulate_Subwindows_Down ( Display_Id : in Display;
                                          Window_Id  : in Window);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Circulate_Subwindows_Up
    --
    --  <Description>
    --
    -- This procedure raises the lowest child of a the specified window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Circulate_Subwindows_Up ( Display_Id : in Display;
                                        Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Configure_Window
    --
    --  <Description>
    --
    --  This procedure reconfigures a window's size, position, border and
    --  stacking order.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Value_Mask : Specifies which values are to be changed.
    --  Changes    : Specifies the values to be changes.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Configure_Window ( Display_Id : in Display;
                                 Window_Id  : in Window;
                                 Value_Mask : in Cw_Mask_Type;
                                 Changes    : in Window_Changes_Record) ;

    --==================================================================
    --  <Subprogram Name>
    --
    --  Create_Pixmap
    --
    --  <Description>
    --
    --  This function creates a pixmap of the width, height and depth
    --  specified, and returns its ID.
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the connection to the X Server.
    --  Drawable_Id : Specifies which screen the pixmap is created on.
    --  Width       : Specifies the width.
    --  Height      : Specifies the Height.
    --  Depth       : Specifies the depth.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Value is raised if the depth is not supported by the root of
    --            the drawable.
    --  Bad_Drawable is raised if Drawable_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --==================================================================

    function Create_Pixmap ( Display_Id  : in Display;
                             Drawable_Id : in Drawable;
                             Width       : in Pixels;
                             Height      : in Pixels;
                             Depth       : in Depth_Type) return Pixmap;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Create_Simple_Window
    --
    --  <Description>
    --
    --  This function creates an unmapped Input_Output subwindow for a
    --  specified parent window.
    --
    --  <Parameters>
    --
    --  Display_Id   : Specifies the connection to the X Server.
    --  Parent       : Specifies the parent window Id.
    --  Bounds       : Specifies the window dimensions.
    --  Border_Width : Specifies the border width.
    --  Border       : Specifies the border pixel value (color).
    --  Background   : Specifies the background pixel value.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Alloc is raised if space for the window could not be allocated
    --  Bad_Window is raised if the parent is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Create_Simple_Window ( Display_Id   : in Display;
                                    Parent       : in Window;
                                    Bounds       : in Rectangle;
                                    Border_Width : in Pixels;
                                    Border       : in Pixel_Value;
                                    Background   : in Pixel_Value)
        return Window;

    --====================================================================
    --  <Subprogram Name>
    --
    --  Create_Window
    --
    --  <Description>
    --
    -- This function creates an unmapped subwindow for a specified parent
    -- window.
    --
    --  <Parameters>
    --
    --  Display_Id   : Specifies the connection to the X Server.
    --  Parent       : Specifies the parent window Id.
    --  Bounds       : Specifies the window dimensions.
    --  Border_Width : Specifies the border width.
    --  Depth        : Specifies the depth.
    --  Class        : Specifies the window's class.
    --  Visuals      : Specifies the visual type.
    --  Value_Mask   : Specifies which window attributes are to be set.
    --  Attributes   : Specifies the values of the window attributes.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Match is raised if border width > 0 for Input_Only windows,
    --            or if the visual type and depth are unsupported for
    --            the screen.
    --  Bad_Alloc is raised if space for the window could not be allocated
    --  Bad_Color is raised if the Color map is invalid.
    --  Bad_Pixmap is raised if a pixmap is invalid.
    --  Bad_Window is raised if the parent is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    function Create_Window
         ( Display_Id   : in Display;
           Parent       : in Window;
           Bounds       : in Rectangle;
           Border_Width : in Pixels;
           Depth        : in Depth_Type;
           Class        : in Window_Class;
           Visuals      : in Visual;
           Value_Mask   : in Wa_Mask_Type;
           Attributes   : in Set_Window_Attributes_Record) return Window;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Destroy_Subwindows
    --
    --  <Description>
    --
    --  This procedure destroys all the subwindows of a specified window.
    --
    --  <Parameters>
    --
    --  Display_Id   : Specifies the connection to the X Server.
    --  Window_Id    : Specifies the Window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Destroy_Subwindows
        ( Display_Id   : in Display;
          Window_Id    : in Window ) ;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Destroy_Window
    --
    --  <Description>
    --
    --  This procedure destroys a window and all of its subwindows.
    --
    --  <Parameters>
    --
    --  Display_Id   : Specifies the connection to the X Server.
    --  Window_Id    : Specifies the Window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Destroy_Window
        ( Display_Id   : in Display;
          Window_Id    : in Window ) ;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Free_Pixmap
    --
    --  <Description>
    --
    --  This procedure frees a previously created pixmap.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Pixmap_Id  : Specifies the pixmap to be freed.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Pixmap is raised if the Pixmap_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Free_Pixmap ( Display_Id : in Display;
                            Pixmap_Id  : in out Pixmap) ;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Geometry
    --
    --  <Description>
    --
    -- This procedure returns the root Id and the current geometry of the
    -- specified drawable.
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the connection to the X Server.
    --  Drawable_Id : Specifies the drawable (pixmap or window).
    --  Root        : Returns the root window id of the drawable.
    --  Bounds      : Returns the bounds of the drawable.
    --  Border_Width: Returns the border width if the drawable is a window
    --  Depths      : Returns the depth of the drawable.
    --  Status      : True if the successful.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Drawable is raised if the drawable Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Geometry ( Display_Id   : in Display;
                             Drawable_Id  : in Drawable;
                             Root         : out Window;
                             Bounds       : out Rectangle;
                             Border_Width : out Pixels;
                             Depths       : out Depth_Type);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Get_Window_Attributes
    --
    --  <Description>
    --
    -- This procedure
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the connection to the X Server.
    --  Window_Id   : Specifies the window.
    --  Attributes  : Returns current attributes of the specified window.
    --  Status      : Returns true if successful.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Get_Window_Attributes
        ( Display_Id : in Display;
          Window_Id  : in Window;
          Attributes : in out Window_Attributes_Record );


    --========================================================================
    --  <Subprogram Name>
    --
    --  Lower_Window
    --
    --  <Description>
    --
    -- This procedure lowers a window so that no sibling window is obscured
    -- by it.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Lower_Window ( Display_Id : in Display;
                             Window_Id  : in Window);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Map_Raised
    --
    --  <Description>
    --
    -- This procedure maps and raises a specified window on the display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Map_Raised ( Display_Id : in Display;
                           Window_Id  : in Window);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Map_Subwindows
    --
    --  <Description>
    --
    -- This procedure maps the subwindows of a specified window
    -- on the display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Map_Subwindows
        ( Display_Id   : in Display;
          Window_Id    : in Window ) ;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Map_Window
    --
    --  <Description>
    --
    -- This procedure maps a specified window on the display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Map_Window ( Display_Id : in Display;
                           Window_Id  : in Window);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Move_Resize_Window
    --
    --  <Description>
    --
    -- This procedure moves and resizes a window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Bounds     : Specifies the new size and origin of the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --===================================================================

    procedure Move_Resize_Window ( Display_Id : in Display;
                                   Window_Id  : in Window;
                                   Bounds     : in Rectangle);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Move_Window
    --
    --  <Description>
    --
    -- This procedure moves a window without changing its size.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Xy         : Specifies the new origin of the window.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Move_Window ( Display_Id : in Display;
                            Window_Id  : in Window;
                            Xy         : in Point);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Query_Tree
    --
    --  <Description>
    --
    --  This procedure returns the list of the immediate subwindows
    -- of the specified window.
    --
    --  <Parameters>
    --
    --  Display_Id  : Specifies the connection to the X Server.
    --  Window_Id   : Specifies the window.
    --  Root        : Returns the root window id for the specified window.
    --  Parent      : Returns parent window id for the specified window.
    --  Children    : Returns a list of children of the specified window.
    --  Status      : True if the operation was successful.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Query_Tree ( Display_Id : in Display;
                           Window_Id  : in Window;
                           Root       : out Window;
                           Parent     : out Window;
                           Children   : out Window_List);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Raise_Window
    --
    --  <Description>
    --
    -- This procedure raises a window so that no sibling window obscures it.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Raise_Window ( Display_Id : in Display;
                             Window_Id  : in Window);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Reparent_Window
    --
    --  <Description>
    --
    -- This procedure changes the parent of a window within a screen.
    -- It is primarily used by window managers.
    --
    --  <Parameters>
    --
    --  Display_Id     : Specifies the connection to the X Server.
    --  Window_Id      : Specifies the window.
    --  Parent         : Specifies the new parent.
    --  Upper_Left     : Specifies the origin of the specified window in
    --                   the new parent.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if either window Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Reparent_Window ( Display_Id : in Display;
                                Window_Id  : in Window;
                                Parent     : in Window;
                                Upper_Left : in Point);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Resize_Window
    --
    --  <Description>
    --
    -- This procedure resizes a window without changing its origin.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Width      : Specifies the new width.
    --  Height     : Specifies the new height.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Resize_Window ( Display_Id : in Display;
                              Window_Id  : in Window;
                              Width      : in Pixels;
                              Height     : in Pixels);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Restack_Windows
    --
    --  <Description>
    --
    -- This procedure restacks a list of windows from top to bottom.
    -- All windows must have the same parent.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Restack_Windows ( Display_Id : in Display;
                                Windows    : in Window_List);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Background
    --
    --  <Description>
    --
    -- This procedure sets the window background to the specified pixel.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Background : Specifies the background to set.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --  Bad_Match is raised if the window is an input only window.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Set_Window_Background ( Display_Id : in Display;
                                      Window_Id  : in Window;
                                      Background : in Pixels);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Background_Pixmap
    --
    --  <Description>
    --
    -- This procedure sets the background of a window to the specified
    -- pixmap.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Background : Specifies the new pixmap.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --  Bad_Match is raised if the window is an input only window.
    --  Bad_Pixmap is raised if a pixmap is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Window_Background_Pixmap ( Display_Id : in Display;
                                             Window_Id  : in Window;
                                             Tile       : in Pixmap);

    --========================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Border
    --
    --  <Description>
    --
    -- This procedure sets the window border to the specified pixel.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Border     : Specifies the new border color.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --  Bad_Pixmap is raised if a pixmap is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Set_Window_Border ( Display_Id : in Display;
                                  Window_Id  : in Window;
                                  Border     : in Pixels);


    --========================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Border_Pixmap
    --
    --  <Description>
    --
    -- This procedure changes the window border tile.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Tile       : Specifies the new border pixmap.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --  Bad_Match is raised if the window is an input only window.
    --  Bad_Pixmap is raised if a pixmap is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --========================================================================

    procedure Set_Window_Border_Pixmap ( Display_Id : in Display;
                                         Window_Id  : in Window;
                                         Tile       : in Pixmap);

    --====================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Border_Width
    --
    --  <Description>
    --
    -- This procedure changes the border width of the window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --  Width      : Specifies the new width.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Set_Window_Border_Width ( Display_Id : in Display;
                                        Window_Id  : in Window;
                                        Width      : in Pixels);


    --======================================================================
    --  <Subprogram Name>
    --
    --  Set_Window_Colormap
    --
    --  <Description>
    --
    --  This procedure sets the specified colormap for the specified window.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window on whose screen you set the colormap.
    --  Map_Id     : Specifies the Color_Map ID.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Match is raised if the Visual is not supported by the screen.
    --  Bad_Window is raised if Window_Id is invalid.
    --  Bad_Color is raised if Map_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --======================================================================

    procedure Set_Window_Colormap ( Display_Id : in Display;
                                    Window_Id  : in Window;
                                    Map_Id     : in Color_Map);


    --====================================================================
    --  <Subprogram Name>
    --
    --  Unmap_Subwindows
    --
    --  <Description>
    --
    -- This procedure unmaps the subwindows of a specified window
    -- on the display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Unmap_Subwindows
        ( Display_Id   : in Display;
          Window_Id    : in Window ) ;


    --====================================================================
    --  <Subprogram Name>
    --
    --  Unmap_Window
    --
    --  <Description>
    --
    -- This procedure unmaps a specified window on the display.
    --
    --  <Parameters>
    --
    --  Display_Id : Specifies the connection to the X Server.
    --  Window_Id  : Specifies the window Id.
    --
    --  <Exceptions Raised>
    --
    --  Bad_Window is raised if the Window_Id is invalid.
    --
    --  <Called By>
    --
    --  External.
    --
    --====================================================================

    procedure Unmap_Window
        ( Display_Id   : in Display;
          Window_Id    : in Window ) ;


end X_Window_Actions ;
